@@ -1084,6 +1084,7 @@ void DrawBoard::loadFiles(QStringList filePaths, bool bInThread,  int loadTypeFo
     doMyRun([ = ]() {
         QMetaObject::invokeMethod(this, [ = ]() {
             if (filePaths.size() > 0) {
+                qInfo() << "Starting to load" << filePaths.size() << "files";
                 d_pri()->processDialog()->reset();
                 d_pri()->processDialog()->setText(QObject::tr("Opening..."));
                 d_pri()->processDialog()->setRange(0, filePaths.count());
@@ -1110,6 +1111,7 @@ void DrawBoard::loadFiles(QStringList filePaths, bool bInThread,  int loadTypeFo
             QFileInfo info(path);
             auto stuffix = info.suffix();
             if (FileHander::supDdfStuffix().contains(stuffix)) {
+                qDebug() << "Loading DDF file:" << path;
 
                 Page *pg = nullptr;
                 QMetaObject::invokeMethod(this, [ =, &pg]() {
@@ -1117,6 +1119,7 @@ void DrawBoard::loadFiles(QStringList filePaths, bool bInThread,  int loadTypeFo
                 }, connectType);
 
                 if (pg != nullptr) {
+                    qDebug() << "File already loaded, switching to existing page:" << path;
                     if (i == filePaths.count()) {
                         setCurrentPage(pg);
                     }
@@ -1125,6 +1128,7 @@ void DrawBoard::loadFiles(QStringList filePaths, bool bInThread,  int loadTypeFo
 
                 PageContext *p = hander.loadDdf(path);
                 if (nullptr == p) {
+                    qWarning() << "Failed to load DDF file:" << path << "Error:" << hander.lastError() << hander.lastErrorDescribe();
                     QMetaObject::invokeMethod(this, [ =, &hander]() {
                         d_pri()->showErrorMsg(hander.lastError(), hander.lastErrorDescribe());
                     }
@@ -1137,9 +1141,11 @@ void DrawBoard::loadFiles(QStringList filePaths, bool bInThread,  int loadTypeFo
                     addPage(p);
                 }, Qt::AutoConnection);
             } else {
+                qDebug() << "Loading image file:" << path;
                 QImage img = hander.loadImage(path);
                 QSize maxSize = Application::drawApplication()->maxPicSize();
                 if (img.isNull()) {
+                    qWarning() << "Failed to load image file:" << path << "Error:" << hander.lastError() << hander.lastErrorDescribe();
                     QMetaObject::invokeMethod(this, [ =, &hander]() {
                         d_pri()->showErrorMsg(hander.lastError(), hander.lastErrorDescribe());
                     }
@@ -1148,7 +1154,7 @@ void DrawBoard::loadFiles(QStringList filePaths, bool bInThread,  int loadTypeFo
                 }
 
                 if (img.size().width() > maxSize.width() || img.size().height() > maximumSize().height()) {
-
+                    qWarning() << "Image size exceeds maximum allowed dimensions:" << img.size();
                     int ret = 0;
                     emit hander.message_waitAnswer(SMessage(QObject::tr("Import failed: no more than 10,000 pixels please"), EWarningMsg), ret);
                     continue;
@@ -1156,7 +1162,7 @@ void DrawBoard::loadFiles(QStringList filePaths, bool bInThread,  int loadTypeFo
 
                 loaded = true;
                 QMetaObject::invokeMethod(this, [ =, &lastChoice]() {
-
+                    qDebug() << "Adding image to current page:" << path;
                     bool bNewPage = false;
                     if (nullptr == currentPage()) {
                         addPage("");
@@ -1167,6 +1173,7 @@ void DrawBoard::loadFiles(QStringList filePaths, bool bInThread,  int loadTypeFo
                     }
 
                     if (0 == loadTypeForImage) {
+                        qDebug() << "Adjusting page rect to fit image";
                         QRectF sceneRect = currentPage()->pageRect();
                         QRectF newRect = sceneRect.adjusted(
                                              (sceneRect.width() > img.width() ? 0 : (sceneRect.width() - img.width()) / 2),
@@ -1179,6 +1186,7 @@ void DrawBoard::loadFiles(QStringList filePaths, bool bInThread,  int loadTypeFo
                         currentPage()->context()->addImage(img, QPointF(), QRectF(), !bNewPage, true);
                         currentPage()->adjustViewScaleRatio();
                     } else if (1 == loadTypeForImage) {
+                        qDebug() << "Adapting image position and rect";
                         QPointF pos;
                         QRectF rect;
                         if (adaptImgPosAndRect(currentPage()->scene(), info.fileName(), img, pos, rect, lastChoice)) {
@@ -1186,18 +1194,18 @@ void DrawBoard::loadFiles(QStringList filePaths, bool bInThread,  int loadTypeFo
                             currentPage()->context()->addImage(img, pos, rect, !bNewPage, true);
                         }
                     }
-
                 }, connectType);
             }
         }
 
         QMetaObject::invokeMethod(this, [ = ]() {
+            qInfo() << "Finished loading files. Successfully loaded:" << loaded;
             d_pri()->processDialog()->setProgressValue(i);
             d_pri()->processDialog()->delayClose();
             if (!loaded && quitIfAllFialed) {
+                qWarning() << "No files were loaded successfully, quitting application";
                 drawApp->quitApp();
             }
-
         }, Qt::AutoConnection);
     }, !bInThread);
 }
@@ -1470,10 +1478,12 @@ void DrawBoard::onFileContextChanged(const QString &path, int tp)
     if (page != nullptr) {
         QFileInfo info(path);
         if (info.exists()) {
+            qInfo() << "File changed externally:" << path;
             enum {EReload, ECLOSE, EJustActiveWindow};
             int ret = noticeFileContextChanged(page, this);
             switch (ret) {
             case EReload: {
+                qDebug() << "Reloading file:" << path;
                 bool autoClose = this->isAutoClose();
                 this->setAutoClose(false);
                 page->close(true);
@@ -1483,14 +1493,17 @@ void DrawBoard::onFileContextChanged(const QString &path, int tp)
                 break;
             }
             case ECLOSE: {
+                qDebug() << "Closing page for file:" << path;
                 page->close(true);
                 break;
             }
             default: {
+                qDebug() << "Just activating window for file:" << path;
                 this->activateWindow();
             }
             }
         } else {
+            qWarning() << "File no longer exists:" << path;
             fileWatcher()->removePath(path);
             page->setFile("");
             page->context()->setDirty(true);
@@ -1504,18 +1517,19 @@ bool DrawBoard::loadDDf(const QString &file)
     bool ret = false;
     auto page = getPageByFile(filePath);
     if (page == nullptr) {
+        qInfo() << "Loading new DDF file:" << filePath;
         PageContext *context = _fileHander->loadDdf(filePath);
         setCurrentPage(addPage(context));
         ret = (context != nullptr);
     } else {
+        qDebug() << "Switching to existing page for file:" << filePath;
         setCurrentPage(page);
     }
 
-    qWarning() << "load result = " << fileHander()->lastError() << fileHander()->lastErrorDescribe();
     auto error = fileHander()->lastError();
     if (error != FileHander::NoError && (FileHander::EUserCancelLoad_OldPen != error && FileHander::EUserCancelLoad_OldBlur != error)) {
+        qWarning() << "Error loading DDF file:" << filePath << "Error:" << error << fileHander()->lastErrorDescribe();
         MessageDlg::execMessage(fileHander()->lastErrorDescribe(), ENormalMsg);
-
     }
     this->activateWindow();
 
@@ -1527,22 +1541,26 @@ bool DrawBoard::loadImage(const QString &file, bool adapt, bool changContexSizeT
     auto filePath = file;
     bool ret = false;
 
+    qInfo() << "Loading image file:" << filePath;
     QImage img = _fileHander->loadImage(filePath);
     ret = !img.isNull();
     if (!img.isNull()) {
         QSize maxSize = Application::drawApplication()->maxPicSize();
         if (img.size().width() > maxSize.width() || img.size().height() > maxSize.height()) {
+            qWarning() << "Image size exceeds maximum allowed dimensions:" << img.size();
             MessageDlg::execMessage(QObject::tr("Import failed: no more than 10,000 pixels please"), EWarningMsg);
             return false;
         }
     }
 
     if (currentPage() == nullptr) {
+        qDebug() << "Creating new page for image";
         setCurrentPage(addPage(""));
         currentPage()->setPageRect(QRectF(QPoint(0, 0), img.size()));
     }
 
     if (changContexSizeToImag) {
+        qDebug() << "Adjusting page rect to fit image";
         QRectF sceneRect = currentPage()->pageRect();
         QRectF newRect = sceneRect.adjusted(
                              (sceneRect.width() > img.width() ? 0 : (sceneRect.width() - img.width()) / 2),
@@ -1559,20 +1577,22 @@ bool DrawBoard::loadImage(const QString &file, bool adapt, bool changContexSizeT
     QRectF rect = QRectF(QPointF(0, 0), img.size());
     bool bAddImg = true;
     if (adapt) {
+        qDebug() << "Adapting image position and rect";
         QFileInfo info(filePath);
         int r = -1;
         bAddImg = adaptImgPosAndRect(currentPage()->scene(), info.fileName(), img, pos, rect, r);
     }
 
     if (bAddImg) {
+        qDebug() << "Adding image to scene";
         currentContext->scene()->clearSelectGroup();
         currentContext->addImage(img, pos, rect, true, true);
         currentPage()->setCurrentTool(selection);
     }
 
-    qWarning() << "load result = " << fileHander()->lastError() << fileHander()->lastErrorDescribe();
     auto error = fileHander()->lastError();
     if (error != FileHander::NoError && (FileHander::EUserCancelLoad_OldPen != error && FileHander::EUserCancelLoad_OldBlur != error)) {
+        qWarning() << "Error loading image file:" << filePath << "Error:" << error << fileHander()->lastErrorDescribe();
         MessageDlg::execMessage(fileHander()->lastErrorDescribe(), ENormalMsg);
     }
     this->activateWindow();
